using System;
using System.Drawing;
using System.Collections;
using System.ComponentModel;
using System.Windows.Forms;
using System.Data;

using System.Runtime.InteropServices; //requirement class

namespace demo_cs
{
	/// <summary>
	/// </summary>
	public class Form1 : System.Windows.Forms.Form
	{
		//1.1 TIFF compression tag definitions.
		//==========================================================================================
		const int AP_TIFF_COMPRESSION_NONE     = 0;  //No compression.
		const int AP_TIFF_COMPRESSION_LZW      = 1;  //1,4,8,24bits(default 4,8,24bits)
		const int AP_TIFF_COMPRESSION_JPEG     = 2;  //Grayscale 8bits,24bits
		const int AP_TIFF_COMPRESSION_PACKBITS = 3;  //4,8,24bits
		const int AP_TIFF_COMPRESSION_CCITTG4  = 4;  //1bit(default 1bit)
		const int AP_TIFF_COMPRESSION_CCITTG3  = 5;  //1bit
		const int AP_TIFF_COMPRESSION_RLE      = 6;  //1bit
		//==========================================================================================

		//1.2 Return code definitions.
		//==========================================================================================
		const int RTN_OK = 1;           //Successful operation.
		const int ERR_UNKNOWN = -99;    //Unknown system error.

		const int ERR_OVER_MAXTHREADS    = -1;  //Over the limit amount of threads
		const int ERR_FILE_UNEXIST       = -2;  //Source PDF file unexist.
		const int ERR_FILE_DAMAGED       = -3;  //Source PDF file is damaged.
		const int ERR_FILE_RESTRICTED    = -4;  //Source PDF file is restricted.
		//==========================================================================================

		//1.3 Windows API definitions.
		//==============================================================================================================
		[DllImport("kernel32.dll")] public static extern int GetTickCount();
		[DllImport("kernel32.dll")] public static extern void CopyMemory(Byte[] dest,int Source, Int32 length);

		const int TRUE = 1;
		const int FALSE = 0;
		//==============================================================================================================

		private System.Windows.Forms.Button btnDemo1;
		private System.Windows.Forms.Button btnDemo2;
		private System.Windows.Forms.ProgressBar m_ProgressBar;
		private System.ComponentModel.Container components = null;

		//Defining an AP Pdf2Tiff ActiveX Control ojbect.
		private AP_PDF2TIFF.AxPdf2Tiff m_AxPdf2Tiff;

		public Form1()
		{
			InitializeComponent();

			//Initialzing AP Pdf2Tiff ActiveX Control object.
			m_AxPdf2Tiff = new AP_PDF2TIFF.AxPdf2TiffClass();
		}

		/// <summary>
		/// </summary>
		protected override void Dispose( bool disposing )
		{
			if( disposing )
			{
				if (components != null) 
				{
					components.Dispose();
				}
			}
			base.Dispose( disposing );
		}

		#region Windows 
		/// <summary>
		/// </summary>
		private void InitializeComponent()
		{
			this.btnDemo1 = new System.Windows.Forms.Button();
			this.btnDemo2 = new System.Windows.Forms.Button();
			this.m_ProgressBar = new System.Windows.Forms.ProgressBar();
			this.SuspendLayout();
			// 
			// btnDemo1
			// 
			this.btnDemo1.Location = new System.Drawing.Point(32, 32);
			this.btnDemo1.Name = "btnDemo1";
			this.btnDemo1.TabIndex = 0;
			this.btnDemo1.Text = "demo1";
			this.btnDemo1.Click += new System.EventHandler(this.btnDemo1_Click);
			// 
			// btnDemo2
			// 
			this.btnDemo2.Location = new System.Drawing.Point(144, 32);
			this.btnDemo2.Name = "btnDemo2";
			this.btnDemo2.TabIndex = 1;
			this.btnDemo2.Text = "demo2";
			this.btnDemo2.Click += new System.EventHandler(this.btnDemo2_Click);
			// 
			// m_ProgressBar
			// 
			this.m_ProgressBar.Location = new System.Drawing.Point(0, 88);
			this.m_ProgressBar.Name = "m_ProgressBar";
			this.m_ProgressBar.Size = new System.Drawing.Size(384, 16);
			this.m_ProgressBar.TabIndex = 2;
			// 
			// Form1
			// 
			this.AutoScaleBaseSize = new System.Drawing.Size(6, 14);
			this.ClientSize = new System.Drawing.Size(384, 102);
			this.Controls.Add(this.m_ProgressBar);
			this.Controls.Add(this.btnDemo2);
			this.Controls.Add(this.btnDemo1);
			this.MaximizeBox = false;
			this.MinimizeBox = false;
			this.Name = "Form1";
			this.Text = "AP Pdf2Tiff ActiveX Control Library Demo!";
			this.ResumeLayout(false);

		}
		#endregion

		/// <summary>
		/// </summary>
		[STAThread]
		static void Main() 
		{
			Application.Run(new Form1());
		}

		//Demo1 - To convert all pages of the pdf document.
		private void btnDemo1_Click(object sender, System.EventArgs e)
		{
			String sFileName = "sample.pdf";

			int iStartTick,iEndTick;
			iStartTick = GetTickCount();

			//Open pdf document and creating a converter.
			int nHandle = m_AxPdf2Tiff.apOpen(sFileName,"","");
			switch( nHandle )
			{
				case ERR_OVER_MAXTHREADS:{ MessageBox.Show("Over the limit amount of threads,please waiting!"); return; };
				case ERR_FILE_UNEXIST:{ MessageBox.Show("Source pdf file unexist!"); return; };
				case ERR_FILE_DAMAGED:{ MessageBox.Show("Source pdf file damaged!"); return; };
				case ERR_FILE_RESTRICTED:{ MessageBox.Show("Source pdf file restricted!"); return; };
			}

			//Setting proerties.
			m_AxPdf2Tiff.sOutDirectory = "demo1";
			m_AxPdf2Tiff.iMultiPages = TRUE; //To generate multipages tiff.
			m_AxPdf2Tiff.iCompression = AP_TIFF_COMPRESSION_LZW;
			m_AxPdf2Tiff.iXDPI = 130;
			m_AxPdf2Tiff.iYDPI = 130;

			//To convert all pages of the pdf document.
			long iPageCount = m_AxPdf2Tiff.apGetPageCount(nHandle);
			for(int iPageNo = 1; iPageNo <= iPageCount; iPageNo++)
			{
				m_AxPdf2Tiff.apConvertPage(nHandle,iPageNo);

				//Setting conversion's progress.
				m_ProgressBar.Value = (int)((iPageNo * 1.0) / iPageCount * 100);
			}

			//Close pdf document and destory the converter.
			m_AxPdf2Tiff.apClose(nHandle);

			//To count conversion's time(ms).
			iEndTick = GetTickCount();
			MessageBox.Show("Conversion successful,it passed " + (iEndTick - iStartTick) + "ms!");
		}

		//demo2 - To convert appointed pdf pages of the pdf document to memory stream.
		private void btnDemo2_Click(object sender, System.EventArgs e)
		{
			String sFileName = "sample.pdf";
			int iStartTick,iEndTick;
			int[] m_Pages = {1, 3, 6, 8, 9, 11};

			iStartTick = GetTickCount();
			//Open pdf document and creating a converter.
			int nHandle = m_AxPdf2Tiff.apOpen(sFileName,"","");
			switch( nHandle )
			{
				case ERR_OVER_MAXTHREADS:{ MessageBox.Show("Over the limit amount of threads,please waiting!"); return; };
				case ERR_FILE_UNEXIST:{ MessageBox.Show("Source pdf file unexist!"); return; };
				case ERR_FILE_DAMAGED:{ MessageBox.Show("Source pdf file damaged!"); return; };
				case ERR_FILE_RESTRICTED:{ MessageBox.Show("Source pdf file restricted!"); return; };
			}

			//Setting proerties.
			m_AxPdf2Tiff.iCompression = AP_TIFF_COMPRESSION_LZW;
			m_AxPdf2Tiff.iXDPI = 110;
			m_AxPdf2Tiff.iYDPI = 110;
			m_AxPdf2Tiff.iXDimensions = 995;
			m_AxPdf2Tiff.iYDimensions = 1287;

			//To convert the appointed pages of the pdf document.
			System.IO.Directory.CreateDirectory("demo2");
			long iPageCount = m_Pages.Length;
			for(int iPos = 0; iPos <= iPageCount - 1; iPos++)
			{
				//You can save image stream to database, to file, or to others, etc.
				m_AxPdf2Tiff.apConvertPageToStream(nHandle,m_Pages[iPos]);

				//Here,it saves the stream to file.
				if( m_AxPdf2Tiff.iStreamSize > 0 )
				{
					//Here,it saves the memory image stream to bytes buffer
					byte[] bBuffer = new byte[m_AxPdf2Tiff.iStreamSize];
					CopyMemory(bBuffer,m_AxPdf2Tiff.iStreamHandle,m_AxPdf2Tiff.iStreamSize);
					
					//Here,it saves the bytes buffer to file.
					string sImgFile = "./demo2/myimg_" + m_Pages[iPos] + ".tif";
					System.IO.FileStream fileStream = new System.IO.FileStream(sImgFile, System.IO.FileMode.OpenOrCreate, System.IO.FileAccess.Write);
					fileStream.Write(bBuffer, 0, m_AxPdf2Tiff.iStreamSize);
					fileStream.Close();
				}

				//Setting conversion's progress.
				m_ProgressBar.Value = (int)((iPos+1)*1.0/m_Pages.Length*100);
			}

			//Close pdf document and destory the converter.
			m_AxPdf2Tiff.apClose(nHandle);

			//To count conversion's time(ms).
			iEndTick = GetTickCount();
			MessageBox.Show("Conversion successful,it passed " + (iEndTick - iStartTick) + "ms!");
		}
	}
}
